import { h } from "@stencil/core";
import { SeriesStyle } from '../../types/types';
import { ChartDataService } from '../../services/chart.data.service';
export class PopoverContentSingle {
    constructor() {
        this.chartListener = ({ detail }) => this.onDataHover(detail);
    }
    connectedCallback() {
        this.chart = this.element.closest('anj-chart');
        this.chart.addEventListener('anjHover', this.chartListener);
    }
    disconnectedCallback() {
        this.chart.removeEventListener('anjHover', this.chartListener);
    }
    onDataHover(newValue) {
        if (newValue.seriesStyle !== SeriesStyle.Single) {
            return;
        }
        if (newValue.axisConfigs.x.labelType === 'date') {
            this.period = ChartDataService.calculateInterval(newValue.data[0]);
        }
        this.activeData = newValue;
    }
    xDisplayValue() {
        return ChartDataService.xFormatter(this.period, this.activeData.axisConfigs.x, this.activeData.data[0][this.activeData.activeIndex].x);
    }
    yDisplayValue() {
        return ChartDataService.yFormatter(this.activeData.axisConfigs.y, this.activeData.data[0][this.activeData.activeIndex].y);
    }
    render() {
        return (this.activeData) ? [
            h("div", null, this.xDisplayValue()),
            h("div", { class: "anj-value" }, this.yDisplayValue())
        ] : undefined;
    }
    static get is() { return "anj-popover-content-single"; }
    static get originalStyleUrls() { return {
        "$": ["popover-content-single.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["popover-content-single.css"]
    }; }
    static get states() { return {
        "activeData": {}
    }; }
    static get elementRef() { return "element"; }
}
