import { ChartD3Service } from '../../services/chart.d3.service';
import { COLOR_WHEEL } from '../../services/color-wheel';
export class Series {
    constructor() {
        /**
         * If true will render an area for single line series only
         */
        this.area = false;
    }
    onDataChange() {
        this.anjSeriesDidLoad.emit();
    }
    componentDidLoad() {
        this.anjSeriesDidLoad.emit();
    }
    componentDidUnload() {
        this.anjSeriesDidUnload.emit();
    }
    async init(svg, x, y, data, index, dims, multiSeries, secondaryIndex) {
        this.color = this.color || COLOR_WHEEL[secondaryIndex || index || 0];
        switch (this.type) {
            case 'column':
                return this.column(svg, x, y, data, index, dims, multiSeries);
            case 'stacked-column':
                return this.stackedColumn(svg, x, y, data, index, dims);
            case 'line':
                // this.area = true;
                return this.line(svg, x, y, data, index, dims, multiSeries, secondaryIndex !== undefined);
        }
    }
    column(svg, x, y, data, index, dims, x1) {
        return ChartD3Service.addColumn(svg, x, x1, y, data, this.color, dims, index);
    }
    line(svg, x, y, data, index, dims, multiSeries, isSecondary) {
        const line = ChartD3Service.addLine(svg, x, y, data, this.color, isSecondary);
        // Multi gets scrubber, single gets area if is all positive
        if (multiSeries) {
            ChartD3Service.addScrubbers(svg, x, data, dims, index);
        }
        if (this.area) {
            ChartD3Service.addArea(svg, line, y, data, this.color);
        }
        ChartD3Service.addPoints(svg, x, y, data, this.color, index);
        return this.color;
    }
    stackedColumn(svg, x, y, data, index, dims) {
        const bars = ChartD3Service.addStackedColumn(svg, x, y, data, this.color);
        ChartD3Service.addStackedScrubbers(svg, x, data, dims, index);
        return { bars, color: this.color };
    }
    static get is() { return "anj-series"; }
    static get properties() { return {
        "area": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "If true will render an area for single line series only"
            },
            "attribute": "area",
            "reflect": false,
            "defaultValue": "false"
        },
        "color": {
            "type": "string",
            "mutable": true,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The display color of the series. If none is chosen it will be assigned based on design system defaults."
            },
            "attribute": "color",
            "reflect": false
        },
        "data": {
            "type": "unknown",
            "mutable": false,
            "complexType": {
                "original": "CoordinateData[]",
                "resolved": "CoordinateData[]",
                "references": {
                    "CoordinateData": {
                        "location": "import",
                        "path": "../../types/types"
                    }
                }
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "Array of coordinates in {x, y} format for the series."
            }
        },
        "name": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The display label for the series."
            },
            "attribute": "name",
            "reflect": false
        },
        "type": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "'column' | 'line' | 'stacked-column'",
                "resolved": "\"column\" | \"line\" | \"stacked-column\"",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The series display type.\nOptions are `\"column\"`, `\"line\"`, and `\"stacked-column\"`."
            },
            "attribute": "type",
            "reflect": true
        }
    }; }
    static get events() { return [{
            "method": "anjSeriesDidLoad",
            "name": "anjSeriesDidLoad",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "Emitted when a series has loaded"
            },
            "complexType": {
                "original": "void",
                "resolved": "void",
                "references": {}
            }
        }, {
            "method": "anjSeriesDidUnload",
            "name": "anjSeriesDidUnload",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "Emitted when a series has unloaded"
            },
            "complexType": {
                "original": "void",
                "resolved": "void",
                "references": {}
            }
        }]; }
    static get methods() { return {
        "init": {
            "complexType": {
                "signature": "(svg: any, x: any, y: any, data: CoordinateData[], index: number, dims: any, multiSeries?: any, secondaryIndex?: number) => Promise<any>",
                "parameters": [{
                        "tags": [],
                        "text": ""
                    }, {
                        "tags": [],
                        "text": ""
                    }, {
                        "tags": [],
                        "text": ""
                    }, {
                        "tags": [],
                        "text": ""
                    }, {
                        "tags": [],
                        "text": ""
                    }, {
                        "tags": [],
                        "text": ""
                    }, {
                        "tags": [],
                        "text": ""
                    }, {
                        "tags": [],
                        "text": ""
                    }],
                "references": {
                    "Promise": {
                        "location": "global"
                    },
                    "CoordinateData": {
                        "location": "import",
                        "path": "../../types/types"
                    }
                },
                "return": "Promise<any>"
            },
            "docs": {
                "text": "",
                "tags": []
            }
        }
    }; }
    static get watchers() { return [{
            "propName": "data",
            "methodName": "onDataChange"
        }]; }
}
